@@ -36,11 +36,13 @@ import (
 	_ "github.com/wader/fq/format/markdown"
 	_ "github.com/wader/fq/format/math"
 	_ "github.com/wader/fq/format/matroska"
+	_ "github.com/wader/fq/format/midi"
 	_ "github.com/wader/fq/format/moc3"
 	_ "github.com/wader/fq/format/mp3"
 	_ "github.com/wader/fq/format/mp4"
 	_ "github.com/wader/fq/format/mpeg"
 	_ "github.com/wader/fq/format/msgpack"
+	_ "github.com/wader/fq/format/negentropy"
 	_ "github.com/wader/fq/format/nes"
 	_ "github.com/wader/fq/format/ogg"
 	_ "github.com/wader/fq/format/opentimestamps"
@@ -52,12 +54,14 @@ import (
 	_ "github.com/wader/fq/format/protobuf"
 	_ "github.com/wader/fq/format/riff"
 	_ "github.com/wader/fq/format/rtmp"
+	_ "github.com/wader/fq/format/tap"
 	_ "github.com/wader/fq/format/tar"
 	_ "github.com/wader/fq/format/text"
 	_ "github.com/wader/fq/format/tiff"
 	_ "github.com/wader/fq/format/tls"
 	_ "github.com/wader/fq/format/toml"
 	_ "github.com/wader/fq/format/tzif"
+	_ "github.com/wader/fq/format/tzx"
 	_ "github.com/wader/fq/format/vorbis"
 	_ "github.com/wader/fq/format/vpx"
 	_ "github.com/wader/fq/format/wasm"
