@@ -29,9 +29,9 @@ func VarZigZag(d *decode.D) int64 {
 	return 0
 }
 
-func decodeLongFn(sms ...scalar.Mapper) (DecodeFn, error) {
+func decodeLongFn(sms ...scalar.SintMapper) (DecodeFn, error) {
 	// Int and long values are written using variable-length zig-zag coding.
 	return func(name string, d *decode.D) any {
-		return d.FieldSFn(name, VarZigZag, sms...)
+		return d.FieldSintFn(name, VarZigZag, sms...)
 	}, nil
 }
