@@ -14,12 +14,13 @@ import (
 )
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.DNS,
-		Description: "DNS packet",
-		Groups:      []string{format.UDP_PAYLOAD},
-		DecodeFn:    dnsUDPDecode,
-	})
+	interp.RegisterFormat(
+		format.DNS,
+		&decode.Format{
+			Description: "DNS packet",
+			Groups:      []*decode.Group{format.UDP_Payload},
+			DecodeFn:    dnsUDPDecode,
+		})
 }
 
 const (
@@ -262,7 +263,7 @@ func dnsDecode(d *decode.D, hasLengthHeader bool) any {
 }
 
 func dnsUDPDecode(d *decode.D) any {
-	var upi format.UDPPayloadIn
+	var upi format.UDP_Payload_In
 	if d.ArgAs(&upi) {
 		upi.MustIsPort(d.Fatalf, format.UDPPortDomain, format.UDPPortMDNS)
 	}
