@@ -9,7 +9,6 @@ import (
 	"fmt"
 
 	"github.com/wader/fq/format"
-	"github.com/wader/fq/internal/mathx"
 	"github.com/wader/fq/pkg/bitio"
 	"github.com/wader/fq/pkg/decode"
 	"github.com/wader/fq/pkg/interp"
@@ -65,7 +64,7 @@ func flacDecode(d *decode.D) any {
 
 			samplesInFrame := ffo.Samples
 			if streamTotalSamples > 0 {
-				samplesInFrame = mathx.Min(streamTotalSamples-streamDecodedSamples, ffo.Samples)
+				samplesInFrame = min(streamTotalSamples-streamDecodedSamples, ffo.Samples)
 			}
 			frameStreamSamplesBuf := ffo.SamplesBuf[0 : samplesInFrame*uint64(ffo.Channels*ffo.BitsPerSample/8)]
 			framesNDecodedSamples += ffo.Samples
