@@ -268,7 +268,7 @@ func decodeBoxWithParentData(ctx *decodeContext, d *decode.D, parentData any, ex
 
 	if ctx.opts.AllowTruncated && dataSize > uint64(d.BitsLeft()/8) {
 		dataSize = uint64(d.BitsLeft() / 8)
-
+		d.FieldValueUint("truncated_size", dataSize)
 	}
 
 	if parentData != nil {
@@ -591,13 +591,14 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 				size := d.FieldU32("size")
 				dataFormat := d.FieldUTF8("type", 4, dataFormatNames, scalar.ActualTrimSpace)
 				subType := ""
-				if t := ctx.currentTrack(); t != nil {
-					t.sampleDescriptions = append(t.sampleDescriptions, sampleDescription{
+				track := ctx.currentTrack()
+				if track != nil {
+					track.sampleDescriptions = append(track.sampleDescriptions, sampleDescription{
 						dataFormat: dataFormat,
 					})
 
-					if t.seenHdlr {
-						subType = t.subType
+					if track.seenHdlr {
+						subType = track.subType
 					} else {
 						// TODO: seems to be ffmpeg mov.c, where is this documented in specs?
 						// no hdlr box found, guess using dataFormat
@@ -617,7 +618,6 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 
 					switch subType {
 					case "soun", "vide":
-
 						version := d.FieldU16("version")
 						d.FieldU16("revision_level")
 						d.FieldU32("max_packet_size") // TODO: vendor for some subtype?
@@ -626,9 +626,10 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 						case "soun":
 							// AudioSampleEntry
 							// https://developer.apple.com/library/archive/documentation/QuickTime/QTFF/QTFFChap3/qtff3.html#//apple_ref/doc/uid/TP40000939-CH205-SW1
+							var numAudioChannels uint64
 							switch version {
 							case 0:
-								d.FieldU16("num_audio_channels")
+								numAudioChannels = d.FieldU16("num_audio_channels")
 								d.FieldU16("sample_size")
 								d.FieldU16("compression_id")
 								d.FieldU16("packet_size")
@@ -637,7 +638,7 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 									decodeBoxes(ctx, d)
 								}
 							case 1:
-								d.FieldU16("num_audio_channels")
+								numAudioChannels = d.FieldU16("num_audio_channels")
 								d.FieldU16("sample_size")
 								d.FieldU16("compression_id")
 								d.FieldU16("packet_size")
@@ -657,7 +658,7 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 								d.FieldU32("always_65536")
 								d.FieldU32("size_of_struct_only")
 								d.FieldF64("audio_sample_rate")
-								d.FieldU32("num_audio_channels")
+								numAudioChannels = d.FieldU32("num_audio_channels")
 								d.FieldU32("always_7f000000")
 								d.FieldU32("const_bits_per_channel")
 								d.FieldU32("format_specific_flags")
@@ -669,6 +670,9 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 							default:
 								d.FieldRawLen("data", d.BitsLeft())
 							}
+							if track != nil {
+								track.stsdNumAudioChannels = numAudioChannels
+							}
 						case "vide":
 							// VideoSampleEntry
 							// TODO: version 0 and 1 same?
@@ -1077,31 +1081,44 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		t := trun{
 			dataOffset: dataOffset,
 		}
-		d.FieldArray("samples", func(d *decode.D) {
-			for i := uint64(0); i < sampleCount; i++ {
-				sampleSize := m.defaultSampleSize
-				d.FieldStruct("sample", func(d *decode.D) {
-					if sampleDurationPresent {
-						d.FieldU32("sample_duration")
-					}
-					if sampleSizePresent {
-						sampleSize = int64(d.FieldU32("sample_size"))
-					}
-					if sampleFlagsPresent {
-						d.FieldStruct("sample_flags", decodeSampleFlags)
-					}
-					if sampleCompositionTimeOffsetsPresent {
-						if version == 0 {
-							d.FieldU32("sample_composition_time_offset")
-						} else {
-							d.FieldS32("sample_composition_time_offset")
-						}
-					}
-				})
 
-				t.samplesSizes = append(t.samplesSizes, sampleSize)
+		hasSampleFlags := (false ||
+			sampleCompositionTimeOffsetsPresent ||
+			sampleFlagsPresent ||
+			sampleSizePresent ||
+			sampleDurationPresent)
+
+		if hasSampleFlags {
+			d.FieldArray("samples", func(d *decode.D) {
+				for i := uint64(0); i < sampleCount; i++ {
+					sampleSize := m.defaultSampleSize
+					d.FieldStruct("sample", func(d *decode.D) {
+						if sampleDurationPresent {
+							d.FieldU32("sample_duration")
+						}
+						if sampleSizePresent {
+							sampleSize = int64(d.FieldU32("sample_size"))
+						}
+						if sampleFlagsPresent {
+							d.FieldStruct("sample_flags", decodeSampleFlags)
+						}
+						if sampleCompositionTimeOffsetsPresent {
+							if version == 0 {
+								d.FieldU32("sample_composition_time_offset")
+							} else {
+								d.FieldS32("sample_composition_time_offset")
+							}
+						}
+					})
+
+					t.samplesSizes = append(t.samplesSizes, sampleSize)
+				}
+			})
+		} else {
+			for i := uint64(0); i < sampleCount; i++ {
+				t.samplesSizes = append(t.samplesSizes, m.defaultSampleSize)
 			}
-		})
+		}
 
 		m.truns = append(m.truns, t)
 	case "tfdt":
@@ -1266,7 +1283,7 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		// ISO-639-2/T as 3*5 bit integers - 0x60
 		d.FieldStrFn("language", func(d *decode.D) string {
 			s := ""
-			for i := 0; i < 3; i++ {
+			for range 3 {
 				s += fmt.Sprintf("%c", int(d.U5())+0x60)
 			}
 			return s
@@ -1350,8 +1367,47 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		d.FieldU32("h_spacing")
 		d.FieldU32("v_spacing")
 	case "uuid":
-		d.FieldRawLen("uuid", 16*8, scalar.RawUUID, uuidNames)
-		d.FieldRawLen("data", d.BitsLeft())
+		uuidBR := d.FieldRawLen("uuid", 16*8, scalar.RawUUID, uuidNames)
+		// TODO: make nicer
+		uuid := d.ReadAllBits(uuidBR)
+
+		switch {
+		case bytes.Equal(uuid, uuidTfxdBytes[:]):
+			// TFXD box based on the latest Smooth Streaming specification (v20241119).
+			// https://winprotocoldocs-bhdugrdyduf5h2e4.b02.azurefd.net/MS-SSTR/%5bMS-SSTR%5d.pdf
+			version := d.FieldU8("version")
+			d.FieldU24("flags")
+			d.FieldStruct("fragment", func(d *decode.D) {
+				if version == 1 {
+					d.FieldU64("absolute_time")
+					d.FieldU64("duration")
+				} else {
+					d.FieldU32("absolute_time")
+					d.FieldU32("duration")
+				}
+			})
+		case bytes.Equal(uuid, uuidTfrfBytes[:]):
+			// TFRF box based on the latest Smooth Streaming specification (v20241119).
+			// https://winprotocoldocs-bhdugrdyduf5h2e4.b02.azurefd.net/MS-SSTR/%5bMS-SSTR%5d.pdf
+			version := d.FieldU8("version")
+			d.FieldU24("flags")
+			fragmentCount := d.FieldU8("fragment_count")
+			d.FieldArray("fragments", func(d *decode.D) {
+				for i := uint64(0); i < fragmentCount; i++ {
+					d.FieldStruct("fragment", func(d *decode.D) {
+						if version == 1 {
+							d.FieldU64("absolute_time")
+							d.FieldU64("duration")
+						} else {
+							d.FieldU32("absolute_time")
+							d.FieldU32("duration")
+						}
+					})
+				}
+			})
+		default:
+			d.FieldRawLen("data", d.BitsLeft())
+		}
 	case "keys":
 		mb := ctx.currentMetaBox()
 		var kb *keysBox
@@ -1828,10 +1884,91 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 	case "ulst":
 		nu := d.FieldU16("nu")
 		d.FieldArray("uids", func(d *decode.D) {
-			for i := 0; i < int(nu); i++ {
+			for range int(nu) {
 				d.FieldRawLen("uid", 128)
 			}
 		})
+	case "pcmC":
+		d.FieldU8("version")
+		d.FieldU24("flags")
+		d.FieldU8("format_flags")
+		d.FieldU8("sample_size")
+	case "chnl":
+		version := d.FieldU8("version")
+		d.FieldU24("flags")
+
+		if version == 0 {
+			hasObjects := false
+			hasChannels := false
+			d.FieldStruct("stream_structure", func(d *decode.D) {
+				d.FieldRawLen("unused", 6)
+				hasObjects = d.FieldBool("objects")
+				hasChannels = d.FieldBool("channels")
+			})
+			if hasChannels {
+				definedLayout := d.FieldU8("defined_layout")
+				if definedLayout == 0 {
+					track := ctx.currentTrack()
+					if track == nil {
+						d.FieldRawLen("rest", d.BitsLeft())
+						break
+					}
+					d.FieldArray("channels", func(d *decode.D) {
+						for i := 0; i < int(track.stsdNumAudioChannels); i++ {
+							d.FieldStruct("channel", func(d *decode.D) {
+								speakerPosition := d.FieldU8("speaker_position")
+								if speakerPosition == 126 {
+									d.FieldS16("azimuth")
+									d.FieldS8("elevation")
+								}
+							})
+						}
+					})
+				} else {
+					d.FieldU64("omitted_channels_map")
+				}
+			}
+			if hasObjects {
+				d.FieldU8("object_count")
+			}
+		} else {
+			hasChannels := false
+			d.FieldStruct("stream_structure", func(d *decode.D) {
+				d.FieldRawLen("unused", 2)
+				d.FieldBool("objects")
+				hasChannels = d.FieldBool("channels")
+			})
+			d.FieldU4("format_ordering")
+			d.FieldU8("base_channel_count")
+			if hasChannels {
+				definedLayout := d.FieldU8("defined_layout")
+				if definedLayout == 0 {
+					layoutChannelCount := d.FieldU8("layout_channel_count")
+					d.FieldArray("channels", func(d *decode.D) {
+						for i := 0; i < int(layoutChannelCount); i++ {
+							d.FieldStruct("channel", func(d *decode.D) {
+								speakerPosition := d.FieldU8("speaker_position")
+								if speakerPosition == 126 {
+									d.FieldS16("azimuth")
+									d.FieldS8("elevation")
+								}
+							})
+						}
+					})
+				} else {
+					d.FieldRawLen("reserved", 4)
+					d.FieldU3("channel_order_definition")
+					omittedChannelsPresent := d.FieldBool("omitted_channels_present")
+					if omittedChannelsPresent {
+						d.FieldU64("omitted_channels_map")
+					}
+				}
+			}
+			// if hasObjects {
+			//    // ISO/IEC 14496-12:2022:
+			//    // > object_count is derived from baseChannelCount
+			// }
+		}
 
 	default:
 		// there are at least 4 ways to encode udta metadata in mov/mp4 files.
