@@ -10,11 +10,12 @@ import (
 )
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.MPEG_ASC,
-		Description: "MPEG-4 Audio Specific Config",
-		DecodeFn:    ascDecoder,
-	})
+	interp.RegisterFormat(
+		format.MPEG_ASC,
+		&decode.Format{
+			Description: "MPEG-4 Audio Specific Config",
+			DecodeFn:    ascDecoder,
+		})
 }
 
 var frequencyIndexHzMap = scalar.UintMapSymUint{
@@ -51,5 +52,5 @@ func ascDecoder(d *decode.D) any {
 	// TODO: GASpecificConfig etc
 	d.FieldRawLen("var_aot_or_byte_align", d.BitsLeft())
 
-	return format.MPEGASCOut{ObjectType: int(objectType)}
+	return format.MPEG_ASC_Out{ObjectType: int(objectType)}
 }
