@@ -42,10 +42,7 @@ func (r *Reader) Read(p []byte) (n int, err error) {
 			return int(copyLen), nil
 		}
 
-		readBytes := len(p)
-		if readBytes < r.minRead {
-			readBytes = r.minRead
-		}
+		readBytes := max(len(p), r.minRead)
 		if readBytes > len(r.cache) {
 			r.cache = make([]byte, readBytes)
 		}
