@@ -495,7 +495,7 @@ func (d *D) TryPeekBits(nBits int) (uint64, error) {
 func (d *D) TryPeekFind(nBits int, seekBits int64, maxLen int64, fn func(v uint64) bool) (int64, uint64, error) {
 	start, err := d.bitBuf.SeekBits(0, io.SeekCurrent)
 	if err != nil {
-		return 0, 0, err
+		return -1, 0, err
 	}
 
 	var count int64
@@ -503,22 +503,20 @@ func (d *D) TryPeekFind(nBits int, seekBits int64, maxLen int64, fn func(v uint6
 	if seekBits < 0 {
 		count = int64(-nBits)
 		if _, err := d.bitBuf.SeekBits(start+count, io.SeekStart); err != nil {
-			return 0, 0, err
+			return -1, 0, err
 		}
 	}
 
 	found := false
 	var v uint64
-	for {
-		if (seekBits > 0 && maxLen > 0 && count >= maxLen) || (seekBits < 0 && maxLen > 0 && count < -maxLen) {
-			break
-		}
+	for !((seekBits > 0 && maxLen > 0 && count >= maxLen) ||
+		(seekBits < 0 && maxLen > 0 && count < -maxLen)) {
 		v, err = d.TryU(nBits)
 		if err != nil {
 			if _, err := d.bitBuf.SeekBits(start, io.SeekStart); err != nil {
-				return 0, 0, err
+				return -1, 0, err
 			}
-			return 0, 0, err
+			return -1, 0, err
 		}
 		if fn(v) {
 			found = true
@@ -526,11 +524,11 @@ func (d *D) TryPeekFind(nBits int, seekBits int64, maxLen int64, fn func(v uint6
 		}
 		count += seekBits
 		if _, err := d.bitBuf.SeekBits(start+count, io.SeekStart); err != nil {
-			return 0, 0, err
+			return -1, 0, err
 		}
 	}
 	if _, err := d.bitBuf.SeekBits(start, io.SeekStart); err != nil {
-		return 0, 0, err
+		return -1, 0, err
 	}
 
 	if !found {
@@ -1285,7 +1283,7 @@ func (d *D) RE(re *regexp.Regexp) []ranges.Range {
 
 	var rs []ranges.Range
 	l := len(locs) / 2
-	for i := 0; i < l; i++ {
+	for i := range l {
 		loc := locs[i*2 : i*2+2]
 		if loc[0] == -1 {
 			rs = append(rs, ranges.Range{Start: -1})
