@@ -87,7 +87,7 @@ func (i *Interp) _registry(c any) any {
 		if f.DefaultInArg != nil {
 			doc := map[string]any{}
 			st := reflect.TypeOf(f.DefaultInArg)
-			for i := 0; i < st.NumField(); i++ {
+			for i := range st.NumField() {
 				f := st.Field(i)
 				if v, ok := f.Tag.Lookup("doc"); ok {
 					doc[mapstruct.CamelToSnake(f.Name)] = v
