@@ -13,6 +13,7 @@ import (
 	"io/fs"
 	"math/big"
 	"path"
+	"slices"
 	"strconv"
 	"strings"
 	"time"
@@ -727,10 +728,7 @@ type pathResolver struct {
 }
 
 func (i *Interp) lookupPathResolver(filename string) (pathResolver, error) {
-	configDir, err := i.OS.ConfigDir()
-	if err != nil {
-		return pathResolver{}, err
-	}
+	configDir, configDirErr := i.OS.ConfigDir()
 
 	resolvePaths := []pathResolver{
 		{
@@ -742,6 +740,9 @@ func (i *Interp) lookupPathResolver(filename string) (pathResolver, error) {
 		},
 		{
 			"@config/", func(filename string) (io.ReadCloser, string, error) {
+				if configDirErr != nil {
+					return nil, "", configDirErr
+				}
 				p := path.Join(configDir, filename)
 				f, err := i.OS.FS().Open(p)
 				return f, p, err
@@ -819,7 +820,7 @@ func (i *Interp) Eval(ctx context.Context, c any, expr string, opts EvalOpts) (g
 		}
 	}
 
-	compilerOpts := append([]gojq.CompilerOption{}, funcCompilerOpts...)
+	compilerOpts := slices.Clone(funcCompilerOpts)
 	compilerOpts = append(compilerOpts, gojq.WithEnvironLoader(ni.OS.Environ))
 	compilerOpts = append(compilerOpts, gojq.WithVariables(variableNames))
 	compilerOpts = append(compilerOpts, gojq.WithModuleLoader(loadModule{
